---
name: Question
about: Ask the Redis developers
title: '[QUESTION]'
labels: ''
assignees: ''

---

Please keep in mind that this issue tracker should be used for reporting bugs or proposing improvements to the Redis server.

Generally, questions about using Redis should be directed to the [community](https://redis.io/community):

* [the mailing list](https://groups.google.com/forum/#!forum/redis-db)
* [the `redis` tag at StackOverflow](http://stackoverflow.com/questions/tagged/redis)
* [/r/redis subreddit](http://www.reddit.com/r/redis)
* [the irc channel #redis](http://webchat.freenode.net/?channels=redis) on freenode

It is also possible that your question was already asked here, so please do a quick issues search before submitting. Lastly, if your question is about one of Redis' [clients](https://redis.io/clients), you may to contact your client's developers for help.

That said, please feel free to replace all this with your question :)